/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

// Wait for the deviceready event before using any of Cordova's device APIs.
// See https://cordova.apache.org/docs/en/latest/cordova/events/events.html#deviceready
document.addEventListener('deviceready', onDeviceReady, false);

function onDeviceReady() {
    // Cordova is now initialized. Have fun!

    console.log('Running cordova-' + cordova.platformId + '@' + cordova.version);
}

/* Hand Writing Scripts */
var hdwrite = {
    upload: function(url) {
        $("#upload_url").html("");
        var myImage = canvas.toDataURL("image/png");
        $.ajax({
            type: "POST",
            url: url,
            data: { imgBase64: myImage },
            success: function(r) { 
                console.log(r); 
                $("#upload_url").html(r);
            },
        }); 
    },
    line: function(start, end, strokeStyle='black', lineWidth=2) {
        ctx.lineWidth = lineWidth;
        ctx.strokeStyle = strokeStyle;
        ctx.beginPath();
        ctx.moveTo(start.x, start.y);
        ctx.lineTo(end.x, end.y);
        ctx.stroke();
        ctx.closePath();
    },  
    getMousePos: function(cs, evt) {
        var rect = cs.getBoundingClientRect();
        return {
          x: evt.clientX - rect.left,
          y: evt.clientY - rect.top
        };
    },  
    getTouchPos: function(cs, evt) {
        var rect = cs.getBoundingClientRect();
        return {
          x: evt.changedTouches[0].clientX - rect.left,
          y: evt.changedTouches[0].clientY - rect.top
        };
    },  
    on_drawing: false,
    addEvent: function() { 
        // canvas mouse events
        canvas.addEventListener("mousedown",function(evt){
            this.on_drawing = true;
            pos_start = hdwrite.getMousePos(this, evt);
        });
        canvas.addEventListener("mouseup",function(evt){
            this.on_drawing = false;
        });     
        canvas.addEventListener("mousemove",function(evt){
            if (this.on_drawing) {
                var pos = hdwrite.getMousePos(this, evt);
                hdwrite.line(pos_start, pos); 
                pos_start = pos;
            }
        });
        // canvas touch events
        canvas.addEventListener("touchstart",function(evt){
            this.on_drawing = true;
            pos_start = hdwrite.getTouchPos(this, evt);
        });
        canvas.addEventListener("touchend",function(evt){
            this.on_drawing = false;
        });     
        canvas.addEventListener("touchmove",function(evt){
            if (this.on_drawing) {
                var pos = hdwrite.getTouchPos(this, evt);
                hdwrite.line(pos_start, pos); 
                pos_start = pos;
            }
        });
    },  
    clear: function() { 
        ctx.clearRect(0, 0, canvas.width, canvas.height);
    },  
};
